@@ -30,15 +30,26 @@ fi
 
 # Get current version (check both locations for compatibility)
 if [ -f /etc/whp-version ]; then
-    CURRENT_VERSION=$(cat /etc/whp-version)
+    CURRENT_VERSION=$(cat /etc/whp-version | tr -cd '0-9.')
 elif [ -f /root/whp/VERSION ]; then
-    CURRENT_VERSION=$(cat /root/whp/VERSION)
+    CURRENT_VERSION=$(cat /root/whp/VERSION | tr -cd '0-9.')
 else
     echo -e "${RED}Error: Cannot determine current WHP version${NC}"
     exit 1
 fi
 
-NEW_VERSION=$(cat "$SCRIPT_DIR/VERSION")
+NEW_VERSION=$(cat "$SCRIPT_DIR/VERSION" | tr -cd '0-9.')
+
+# Validate version format
+if [[ -z "$CURRENT_VERSION" ]] || ! [[ "$CURRENT_VERSION" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]]; then
+    echo -e "${RED}Error: Invalid current version format: $CURRENT_VERSION${NC}"
+    exit 1
+fi
+
+if [[ -z "$NEW_VERSION" ]] || ! [[ "$NEW_VERSION" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]]; then
+    echo -e "${RED}Error: Invalid new version format: $NEW_VERSION${NC}"
+    exit 1
+fi
 
 echo -e "${BLUE}=== WHP Update ===${NC}"
 echo "Current version: $CURRENT_VERSION"
@@ -50,12 +61,62 @@ if [ "$CURRENT_VERSION" = "$NEW_VERSION" ]; then
     exit 0
 fi
 
+# Function to compare versions (YYYY.MM.N format)
+version_compare() {
+    # Validate input format
+    if ! [[ "$1" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]] || ! [[ "$2" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]]; then
+        echo "Error: Invalid version format. Expected YYYY.MM.N" >&2
+        return 1
+    fi
+    
+    # Parse version components
+    local v1_year=$(echo "$1" | cut -d'.' -f1)
+    local v1_month=$(echo "$1" | cut -d'.' -f2)
+    local v1_patch=$(echo "$1" | cut -d'.' -f3)
+    
+    local v2_year=$(echo "$2" | cut -d'.' -f1)
+    local v2_month=$(echo "$2" | cut -d'.' -f2)
+    local v2_patch=$(echo "$2" | cut -d'.' -f3)
+    
+    # Handle empty components with defaults
+    v1_patch=${v1_patch:-0}
+    v2_patch=${v2_patch:-0}
+    
+    # Compare year first
+    if [ "$v1_year" -lt "$v2_year" ]; then
+        echo "-1"
+        return
+    elif [ "$v1_year" -gt "$v2_year" ]; then
+        echo "1"
+        return
+    fi
+    
+    # Years are equal, compare month
+    if [ "$v1_month" -lt "$v2_month" ]; then
+        echo "-1"
+        return
+    elif [ "$v1_month" -gt "$v2_month" ]; then
+        echo "1"
+        return
+    fi
+    
+    # Years and months are equal, compare patch
+    if [ "$v1_patch" -lt "$v2_patch" ]; then
+        echo "-1"
+    elif [ "$v1_patch" -gt "$v2_patch" ]; then
+        echo "1"
+    else
+        echo "0"
+    fi
+}
+
 # Check migration compatibility
 if [ -f "$SCRIPT_DIR/MIGRATION_HISTORY.json" ]; then
     OLDEST_SUPPORTED=$(grep '"oldest_supported"' "$SCRIPT_DIR/MIGRATION_HISTORY.json" | cut -d'"' -f4)
     
-    # Simple version comparison (works for YYYY.MM.N format)
-    if [[ "$CURRENT_VERSION" < "$OLDEST_SUPPORTED" ]]; then
+    # Proper version comparison (YYYY.MM.N format)
+    COMPARE_RESULT=$(version_compare "$CURRENT_VERSION" "$OLDEST_SUPPORTED")
+    if [ "$COMPARE_RESULT" = "-1" ]; then
         echo -e "${RED}Error: Your current version ($CURRENT_VERSION) is too old.${NC}"
         echo "This update package only supports versions $OLDEST_SUPPORTED and newer."
         echo "Please update to an intermediate version first."
@@ -112,13 +173,47 @@ MIGRATION_DIR="$3"
 
 # Function to compare versions (YYYY.MM.N format)
 version_compare() {
-    # Convert version to comparable number: YYYYMMN
-    local v1=$(echo "$1" | sed 's/\.//g')
-    local v2=$(echo "$2" | sed 's/\.//g')
+    # Validate input format
+    if ! [[ "$1" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]] || ! [[ "$2" =~ ^[0-9]{4}\.[0-9]{1,2}\.[0-9]+$ ]]; then
+        echo "Error: Invalid version format. Expected YYYY.MM.N" >&2
+        return 1
+    fi
     
-    if [ "$v1" -lt "$v2" ]; then
+    # Parse version components
+    local v1_year=$(echo "$1" | cut -d'.' -f1)
+    local v1_month=$(echo "$1" | cut -d'.' -f2)
+    local v1_patch=$(echo "$1" | cut -d'.' -f3)
+    
+    local v2_year=$(echo "$2" | cut -d'.' -f1)
+    local v2_month=$(echo "$2" | cut -d'.' -f2)
+    local v2_patch=$(echo "$2" | cut -d'.' -f3)
+    
+    # Handle empty components with defaults
+    v1_patch=${v1_patch:-0}
+    v2_patch=${v2_patch:-0}
+    
+    # Compare year first
+    if [ "$v1_year" -lt "$v2_year" ]; then
         echo "-1"
-    elif [ "$v1" -gt "$v2" ]; then
+        return
+    elif [ "$v1_year" -gt "$v2_year" ]; then
+        echo "1"
+        return
+    fi
+    
+    # Years are equal, compare month
+    if [ "$v1_month" -lt "$v2_month" ]; then
+        echo "-1"
+        return
+    elif [ "$v1_month" -gt "$v2_month" ]; then
+        echo "1"
+        return
+    fi
+    
+    # Years and months are equal, compare patch
+    if [ "$v1_patch" -lt "$v2_patch" ]; then
+        echo "-1"
+    elif [ "$v1_patch" -gt "$v2_patch" ]; then
         echo "1"
     else
         echo "0"
